@@ -14,13 +14,16 @@
 
 //! Base code for authentication.
 
+#![allow(missing_docs)]
+
+use std::fmt;
+
 use hyper::{Client, Url};
 use hyper::client::IntoUrl;
 use hyper::error::ParseError;
 use time::PreciseTime;
 
-use super::super::ApiError;
-use super::super::session::AuthenticatedClient;
+use super::super::{ApiError, Session};
 
 
 /// Authentication token.
@@ -43,16 +46,23 @@ pub trait AuthMethod: Clone + Send {
     fn get_endpoint(&self, service_type: &str,
                     endpoint_interface: Option<&str>,
                     region: Option<&str>,
-                    client: &AuthenticatedClient)
+                    session: &Session<Self>)
         -> Result<Url, ApiError>;
 }
 
 /// Authentication method that provides no authentication (uses a fake token).
-#[derive(Clone)]
+#[derive(Clone, Debug)]
 pub struct NoAuth {
     endpoint: Url
 }
 
+impl fmt::Debug for AuthToken {
+    // FIXME: PreciseTime does not implement Debug
+    fn fmt(&self, f: &mut fmt::Formatter) -> Result<(), fmt::Error> {
+        write!(f, "AuthToken( token: {} )", self.token)
+    }
+}
+
 impl NoAuth {
     /// Create a new fake authentication method using a fixed endpoint.
     pub fn new<U>(endpoint: U) -> Result<NoAuth, ParseError> where U: IntoUrl {
@@ -76,7 +86,7 @@ impl AuthMethod for NoAuth {
     fn get_endpoint(&self, _service_type: &str,
                     _endpoint_interface: Option<&str>,
                     _region: Option<&str>,
-                    _client: &AuthenticatedClient)
+                    _client: &Session<NoAuth>)
             -> Result<Url, ApiError> {
         Ok(self.endpoint.clone())
     }
@@ -86,7 +96,7 @@ impl AuthMethod for NoAuth {
 pub mod test {
     use hyper;
 
-    use super::super::super::session::test::new_client;
+    use super::super::super::session::test::new_session;
 
     use super::{AuthMethod, NoAuth};
 
@@ -117,7 +127,7 @@ pub mod test {
     fn test_noauth_get_endpoint() {
         let a = NoAuth::new("http://127.0.0.1:8080/v1").unwrap();
         let e = a.get_endpoint("foobar", None, None,
-                               &new_client("token")).unwrap();
+                               &new_session("token")).unwrap();
         assert_eq!(e.scheme(), "http");
         assert_eq!(e.host_str().unwrap(), "127.0.0.1");
         assert_eq!(e.port().unwrap(), 8080u16);
