@@ -19,6 +19,15 @@
 
 #![crate_name = "openstack"]
 #![crate_type = "lib"]
+#![warn(missing_docs,
+        missing_debug_implementations,
+        missing_copy_implementations,
+        trivial_casts,
+        trivial_numeric_casts,
+        unsafe_code,
+        unstable_features,
+        unused_import_braces,
+        unused_qualifications)]
 
 #[macro_use]
 extern crate hyper;
@@ -34,6 +43,9 @@ extern crate serde_derive;
 extern crate serde_json;
 extern crate time;
 
+#[cfg(test)] #[macro_use]
+extern crate yup_hyper_mock;
+
 pub mod auth;
 mod common;
 pub mod identity;
@@ -41,3 +53,4 @@ pub mod session;
 pub mod utils;
 
 pub use common::ApiError;
+pub use session::Session;
